@@ -6,6 +6,7 @@ from functools import partial
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Set, Tuple, Type, Union, cast
 
 from pypika import JoinType, Parameter, Query, Table
+from pypika.terms import ArithmeticExpression
 
 from tortoise.exceptions import OperationalError
 from tortoise.fields.base import Field
@@ -176,7 +177,11 @@ class BaseExecutor:
         ]
         await self.db.execute_many(self.insert_query, values_lists)
 
-    def get_update_sql(self, update_fields: Optional[List[str]]) -> str:
+    def get_update_sql(
+        self,
+        update_fields: Optional[List[str]],
+        arithmetic: Optional[Dict[str, ArithmeticExpression]],
+    ) -> str:
         """
         Generates the SQL for updating a model depending on provided update_fields.
         Result is cached for performance.
@@ -184,7 +189,7 @@ class BaseExecutor:
         key = ",".join(update_fields) if update_fields else ""
         if key in self.update_cache:
             return self.update_cache[key]
-
+        arithmetic = arithmetic or {}
         table = self.model._meta.basetable
         query = self.db.query_class.update(table)
         count = 0
@@ -192,8 +197,11 @@ class BaseExecutor:
             db_column = self.model._meta.fields_db_projection[field]
             field_object = self.model._meta.fields_map[field]
             if not field_object.pk:
-                query = query.set(db_column, self.parameter(count))
-                count += 1
+                if db_column not in arithmetic.keys():
+                    query = query.set(db_column, self.parameter(count))
+                    count += 1
+                else:
+                    query = query.set(db_column, arithmetic.get(db_column))
 
         query = query.where(table[self.model._meta.db_pk_column] == self.parameter(count))
 
@@ -203,13 +211,20 @@ class BaseExecutor:
     async def execute_update(
         self, instance: "Union[Type[Model], Model]", update_fields: Optional[List[str]]
     ) -> int:
-        values = [
-            self.column_map[field](getattr(instance, field), instance)
-            for field in update_fields or self.model._meta.fields_db_projection.keys()
-            if not self.model._meta.fields_map[field].pk
-        ]
+        values = []
+        arithmetic = {}
+        for field in update_fields or self.model._meta.fields_db_projection.keys():
+            if not self.model._meta.fields_map[field].pk:
+                instance_field = getattr(instance, field)
+                if isinstance(instance_field, ArithmeticExpression):
+                    arithmetic[field] = instance_field
+                else:
+                    value = self.column_map[field](instance_field, instance)
+                    values.append(value)
         values.append(self.model._meta.pk.to_db_value(instance.pk, instance))
-        return (await self.db.execute_query(self.get_update_sql(update_fields), values))[0]
+        return (
+            await self.db.execute_query(self.get_update_sql(update_fields, arithmetic), values)
+        )[0]
 
     async def execute_delete(self, instance: "Union[Type[Model], Model]") -> int:
         return (
