@@ -21,7 +21,6 @@ except ImportError:  # pragma: nocoverage
 
     parse_datetime = functools.partial(parse_date, default_timezone=None)
 
-
 if TYPE_CHECKING:  # pragma: nocoverage
     from tortoise.models import Model
 
@@ -79,7 +78,7 @@ class IntField(Field, int):
     @property
     def constraints(self) -> dict:
         return {
-            "ge": 1 if self.generated else -2147483648,
+            "ge": 1 if self.generated or self.reference else -2147483648,
             "le": 2147483647,
         }
 
@@ -112,7 +111,7 @@ class BigIntField(Field, int):
     @property
     def constraints(self) -> dict:
         return {
-            "ge": 1 if self.generated else -9223372036854775808,
+            "ge": 1 if self.generated or self.reference else -9223372036854775808,
             "le": 9223372036854775807,
         }
 
@@ -145,7 +144,7 @@ class SmallIntField(Field, int):
     @property
     def constraints(self) -> dict:
         return {
-            "ge": 1 if self.generated else -32768,
+            "ge": 1 if self.generated or self.reference else -32768,
             "le": 32767,
         }
 
@@ -484,9 +483,13 @@ class IntEnumFieldInstance(SmallIntField):
         return self.enum_type(value) if value is not None else None
 
     def to_db_value(
-        self, value: Union[IntEnum, None], instance: "Union[Type[Model], Model]"
+        self, value: Union[IntEnum, None, int], instance: "Union[Type[Model], Model]"
     ) -> Union[int, None]:
-        return int(value.value) if value is not None else None
+        if isinstance(value, IntEnum):
+            return int(value.value)
+        elif isinstance(value, int):
+            return int(self.enum_type(value))
+        return value
 
 
 IntEnumType = TypeVar("IntEnumType", bound=IntEnum)
@@ -503,6 +506,8 @@ def IntEnumField(
     The description of the field is set automatically if not specified to a multiline list of
     "name: value" pairs.
 
+    **Note**: Valid int value of ``enum_type`` is acceptable.
+
     ``enum_type``:
         The enum class
     ``description``:
@@ -539,9 +544,13 @@ class CharEnumFieldInstance(CharField):
         return self.enum_type(value) if value is not None else None
 
     def to_db_value(
-        self, value: Union[Enum, None], instance: "Union[Type[Model], Model]"
+        self, value: Union[Enum, None, str], instance: "Union[Type[Model], Model]"
     ) -> Union[str, None]:
-        return str(value.value) if value is not None else None
+        if isinstance(value, Enum):
+            return str(value.value)
+        elif isinstance(value, str):
+            return str(self.enum_type(value).value)
+        return value
 
 
 CharEnumType = TypeVar("CharEnumType", bound=Enum)
@@ -562,6 +571,8 @@ def CharEnumField(
     char fields is automatically detected. So if later you update the enum, you need to update your
     table schema as well.
 
+    **Note**: Valid str value of ``enum_type`` is acceptable.
+
     ``enum_type``:
         The enum class
     ``description``:
